@@ -11,7 +11,7 @@ use Cache::FileCache;
 use Storable qw(freeze thaw);
 use POSIX;
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 ###########################################
 sub new {
@@ -434,6 +434,7 @@ sub files_commit {
     my($self, @files) = @_;
 
     my $dir = $self->{local_root};
+    cd $dir;
 
     for my $file (@files) {
         blurt rand(1E10), $file;
@@ -666,6 +667,8 @@ under the C<revs> key:
                     file2.txt => [1.1, 1.2]
                   }
 
+=back
+
 =head2 Use the same script for multiple hooks
 
 You can call the same trigger script in multiple hooks. Since the parameters
@@ -777,9 +780,15 @@ pid within the expiration timeframe, a clash will occur.
 
 =head1 TODO List
 
+    * Try filenames with commas, spaces, and newlines
+    * tests for optional arguments
     * methods vs. hash access
     * no STDIN on loginfo => hangs
 
+=head1 SEE ALSO
+
+http://ximbiot.com/cvs/wiki/index.php?title=CVS--Concurrent_Versions_System_v1.12.12.1:_Reference_manual_for_Administrative_files#SEC184
+
 =head1 LEGALESE
 
 Copyright 2006 by Mike Schilli, all rights reserved.
